summaryrefslogtreecommitdiff
path: root/cogl/cogl-pipeline.h
diff options
context:
space:
mode:
Diffstat (limited to 'cogl/cogl-pipeline.h')
-rw-r--r--cogl/cogl-pipeline.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/cogl/cogl-pipeline.h b/cogl/cogl-pipeline.h
index d990e244..20f54fa6 100644
--- a/cogl/cogl-pipeline.h
+++ b/cogl/cogl-pipeline.h
@@ -95,18 +95,18 @@ cogl_pipeline_copy (CoglPipeline *source);
/**
* cogl_is_pipeline:
- * @handle: A CoglHandle
+ * @object: A #CoglObject
*
- * Gets whether the given handle references an existing pipeline object.
+ * Gets whether the given @object references an existing pipeline object.
*
* Return value: %TRUE if the handle references a #CoglPipeline,
* %FALSE otherwise
*
* Since: 2.0
* Stability: Unstable
*/
gboolean
-cogl_is_pipeline (CoglHandle handle);
+cogl_is_pipeline (void *object);
/**
* CoglPipelineLayerCallback:
@@ -95,18 +95,18 @@ cogl_pipeline_copy (CoglPipeline *source);
*
- * Return value: %TRUE if the handle references a #CoglPipeline,
+ * Return value: %TRUE if the @object references a #CoglPipeline,
* %FALSE otherwise
*